@@ -17,12 +17,8 @@ from PyQt4 import QtGui, QtCore
 
 from rest_in_peace_gui import *
 
-CURRENTVERSION = "0.2.0"
-
-
 #mytimer = timer.Timer()
 
-
 class MyForm(QtGui.QMainWindow):
     enableLogging = False;
     enableAlarm = False;
@@ -60,7 +56,6 @@ class MyForm(QtGui.QMainWindow):
         QtCore.QObject.connect(self.ui.actionMenuAbout, QtCore.SIGNAL('triggered()'), self.showAbout)
         QtCore.QObject.connect(self.ui.actionMenuTips, QtCore.SIGNAL('triggered()'), self.showTips)
 
-
         # get Current registered Cell ID
         # can't get this to work in straight python, so cheat and run the command in bash
         # Many thanks to the maemo.org wiki!
@@ -104,8 +99,7 @@ class MyForm(QtGui.QMainWindow):
                 except:
                     self.cellID_list[cellName] = [self.cellID_list[cellName],]
 
-#            print self.cellID_list
-            #self.cellID_list.sort() #TODO: cellnames hierarchy
+            #TODO: cellnames hierarchy
 
 
     def doStart(self):
@@ -124,7 +118,7 @@ class MyForm(QtGui.QMainWindow):
     def enableSaveButton(self, text):
         self.ui.pushButtonFav.setEnabled( True )
 
-    # Could probanbly do with defaulting this to "on"
+    # Could probably do with defaulting this to "on"
     def setAlarm(self, value):
         self.enableAlarm = not self.enableAlarm
         self.ui.checkBoxAlarm.setTristate(self.enableAlarm)
@@ -182,7 +176,7 @@ class MyForm(QtGui.QMainWindow):
 
     def showTips(self):
         tipsString = "Choose one of the favorites, enable the alarm and hit 'Go'. As long as the app is running, it will sound an alarm when the phone registers itself with the GSM basestation at the destination.<br>To save the currently registered CellID, just give it a name in the dropdown and hit 'Add CellID'"
-        #TODO: update tips
+        #TODO: update tips, change the return method
 
 	self.label = QtGui.QLabel(tipsString)
         self.label.setWordWrap(True)
@@ -202,7 +196,7 @@ class MyForm(QtGui.QMainWindow):
 
 
     def showAbout(self):
-        aboutString = "Rest in Peace: v" + CURRENTVERSION + "\nGirish Gopi (rip@gman.me.uk) - version 0.1\nSerhiy Zahoriya (xintx.ua@gmail.com) - version 0.2\nMany thanks to qwerty12, lma, mikec, fatalsaint, Dvortygirl (icon) plus all of t.m.o (& w.m.o)"
+        aboutString = "Rest in Peace:\nGirish Gopi (rip@gman.me.uk) - version 0.1\nSerhiy Zahoriya (xintx.ua@gmail.com) - version 0.2\nMany thanks to qwerty12, lma, mikec, fatalsaint, Dvortygirl (icon) plus all of t.m.o (& w.m.o)"
         QtGui.QMessageBox.information(self, "About R.I.P", aboutString)
 
     def closeTips(self):
@@ -251,15 +245,14 @@ def cell_signal_handler(*args):
                 #sys.exit(myapp.exec_())
                 #myapp.ui.centralwidget.setEnabled(True)
 
-            # Even if there is no alarm, give soem feedback to UI that we're arrived!
+            # Even if there is no alarm, give some feedback to UI that we're arrived!
             myapp.ui.pushButtonStart.setText("We are HERE!")
 
     if( myapp.enableGSMAlarm and (args[3] != 0 and args[4] != 0) ):
         myapp.enableGSMAlarm = False
         myapp.ui.checkBoxGSMAlarm.setChecked(False)
-        add_two_button_alarm("GSM network available")
+        add_two_button_alarm("GSM network available. You may not see it in the status panel if that's not your operator's station.")
 
-#ideas: replace cellid with name if it was saved before.
 if __name__ == '__main__':
     app = QtGui.QApplication(sys.argv)
 
